==> kyamo_0.13.99+0.2a.orig.tar.gz: kyamo-0.2a/src/rcdatei.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Roland Weigert                                  *
 *   roweigert@t-online.de                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


//Settingsdateiklasse mit Speicher und Ladefunktion

#ifndef _RCDATEI_H_
#define _RCDATEI_H_

#include <qstring.h>
#include <qfile.h>
#include <qdir.h>
#include <qtextstream.h>

#include <iostream>
using namespace std;

class rcdatei
{
public:
  QString working_dir;
  QString reading_dir;
  QString destination_dir;
  QString reject_dir;
  QString mp3_dir;
  bool vervollstaendigen;
  QString filter;
  bool rekursiv;
  bool loeschen;
  bool ueberschreiben;
  bool besser;
  bool mysql;
  int bitrate;
  rcdatei()
  {}
  ~rcdatei()
  {}
  void laden();
  void speichern();
};

#endif  //_RCDATEI_H_

==> kyamo_0.40+0.4a.orig.tar.gz: kyamo-0.40a4-2/src/rcdatei.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Roland Weigert                                  *
 *   roweigert@t-online.de                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


//Settingsdateiklasse mit Speicher und Ladefunktion

#ifndef _RCDATEI_H_
#define _RCDATEI_H_

#include <qstring.h>
#include <qfile.h>
#include <qdir.h>
#include <qtextstream.h>

#include <iostream>

using namespace std;

class rcdatei
{
public:
    QString picturename;
    QString pictureformat;
    int picturesize;
    bool savepicture;
    QString reading_dir;
    QString destination_dir;
    QString reject_dir;
    QString mp3_dir;
    bool autocomplete;
    QString filter;
    QString freedbservername;
    QString freedbloginname;
    bool freedbsupport;
    bool musicbrainzsupport;
    bool import;
    bool remove;
    bool overwrite;
    bool better;
    int lamebitrate;
    int gogobitrate;
    int bladeencbitrate;
    int oggencbitrate;
    bool oggencvbr;
    int encodingengine;
    QString lameexe;
    QString lameoptions;
    QString gogoexe;
    QString gogooptions;
    QString bladeencexe;
    QString bladeencoptions;
    QString oggencexe;
    QString oggencoptions;
    int tagversion;
    int databasetype;//replaces mysql-flag in the future
    int playertype;
    QString mplayerexe;
    bool verbose;
    //More players to fillow maybe
    rcdatei()
{}
    ~rcdatei()
    {}
    void load();
    void save();
};

#endif  //_RCDATEI_H_
